==> krusader_1.51.orig.tar.gz: krusader-1.51/krusader/GUI/dirhistoryqueue.h <==
/***************************************************************************
                          dirhistoryqueue.h  -  description
                             -------------------
    begin                : Thu Jan 1 2004
    copyright            : (C) 2004 by Shie Erlich & Rafi Yanai
    email                : 
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DIRHISTORYQUEUE_H
#define DIRHISTORYQUEUE_H

#include <qobject.h>
#include <qstringlist.h>

class ListPanel;

/**
  *@author Shie Erlich & Rafi Yanai
  */

class DirHistoryQueue : public QObject  {
  Q_OBJECT
public: 
	DirHistoryQueue(ListPanel* p);
	~DirHistoryQueue();
  QStringList pathQueue;
  bool checkPath(const QString& path);
  void RemovePath(const QString& path);

private:
  void AddPath(const QString& path);
  void DumpQueue();

  ListPanel* panel;
  
public slots: // Public slots
  /** No descriptions */
  void slotPathChanged(ListPanel* p);
};

#endif

==> krusader_1.80.0.orig.tar.gz: krusader-1.80.0.orig/krusader/GUI/dirhistoryqueue.h <==
/***************************************************************************
                          dirhistoryqueue.h  -  description
                             -------------------
    begin                : Thu Jan 1 2004
    copyright            : (C) 2004 by Shie Erlich & Rafi Yanai
    email                : 
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DIRHISTORYQUEUE_H
#define DIRHISTORYQUEUE_H

#include <qobject.h>
#include <kurl.h>

class ListPanel;

/**
  *@author Shie Erlich & Rafi Yanai
  */

class DirHistoryQueue : public QObject  {
  Q_OBJECT
public: 
	DirHistoryQueue(ListPanel* p);
	~DirHistoryQueue();
	KURL::List urlQueue;
//  bool checkPath(const QString& path);
//  void RemovePath(const QString& path);

public slots: // Public slots
  /** No descriptions */
  void slotPathChanged(ListPanel* p);
private:
//	void addUrl(const KURL& url);
	ListPanel* panel;
};

#endif
